### SCRIPT FOR PAPER METABOLITES##########

library(MetaboList)



######### SECTION 1A: BUILDING LIBRARY FULL--MS POSITIVE

## LOAD MS1 AND ADDUCTS CSV FILES ATTACHED IN SUPPLEMENTARY INFORMATION


library <- read.csv("FullMS1_paper_IS.csv",sep=";")

library <- read.csv("FullMS1_paper.csv",sep=";")

adducts <- read.csv("adducts.csv")


### run Deisotoping for M+H

LibraryH<-Isotopic(library,name=c("M+H"))
LibraryHH<-LibraryH$getpeaksM
LibraryHspectra<-LibraryH$spectrumlist

### run Deisotoping for M+NH4

LibraryNH4<-Isotopic(library,name=c("M+NH4"))
LibraryNH4<-LibraryNH4$getpeaksM
LibraryNH4spectra<-LibraryNH4$spectrumlist


## JOIN RESULTS
pos<-cbind(LibraryHH,LibraryNH4[,5:12])
pos<-cbind(LibraryHH,LibraryNH4[,5:11])

### run Deisotoping for M-H

LibraryHm<-Isotopic(library,name=c("M-H"))
LibraryHHm<-LibraryHm$getpeaksM
LibraryHmspectra<-LibraryHm$spectrumlist
neg<-LibraryHHm


### SECTION 2: LOAD THE FULL-MS LIBRARY CONSTRUCTED


databaseH<-read.csv("M+H.csv",check.names=FALSE)
databaseNH4<-read.csv("M+NH4.csv",check.names=FALSE)
#databaseH<-databaseH[,-1]
#databaseNH4<-databaseNH4[,-1]



databaseHmenos<-read.csv("M-H.csv",check.names=FALSE)
databaseHmenos<-databaseHmenos[,-1]




#### SECTION 3: QTOF FULL-SCAN MS section


file<-"qTOF_Urine.mzXML"


fullmsposH<-FullMS(file, databaseH,mzw = 0.0015,ppm_tol = 10,Peak_Assy=5,rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                   drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                   minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="positive")


fullmsposNH4<-FullMS(file, databaseNH4,mzw = 0.0015,ppm_tol = 10,Peak_Assy=5,rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                     drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                     minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="positive")

annotation_pos<-rbind(fullmsposH$ms,fullmsposNH4$ms)

write.csv2(annotation_pos,file="annotation_pos.csv")


PeakGroupMS1_Qtof<-PeakGroupMS1(annotation_pos)



#### SECTION 4: Q-EXACTIVE FULL SCAN MS
fileCell<-"12.mzXML"


fullmsposHOrbi<-FullMS(fileCell, databaseH,mzw = 0.0015,ppm_tol = 5,rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                       drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                       minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="positive")

fullmsposNH4Orbi<-FullMS(fileCell, databaseNH4,mzw = 0.0015,ppm_tol = 5,rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                         drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                         minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="positive")


annotation_posOrbi<-rbind(fullmsposHOrbi$ms,fullmsposNH4Orbi$ms)


write.csv2(annotation_posOrbi,file="annotation_posOrbi.csv")


fullmsnegHOrbi<-FullMS(fileCell, databaseHmenos,mzw = 0.001,ppm_tol = 5,Peak_Assy=5, rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                       drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                       minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="negative")




annotation_pos_neg_Orbi<-rbind(annotation_posOrbi,fullmsnegHOrbi$ms)

write.csv2(annotation_pos_neg_Orbi,file="annotation_pos_neg_Orbi_Cell.csv")



fileMedium<-"12M.mzXML"

fullmsposHOrbi<-FullMS(fileMedium, databaseH,mzw = 0.001,ppm_tol = 5,Peak_Assy=5,rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                       drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                       minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="positive")

fullmsposNH4Orbi<-FullMS(fileMedium, databaseNH4,mzw = 0.001,ppm_tol = 5,Peak_Assy=5,rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                         drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                         minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="positive")

annotation_posOrbi<-rbind(fullmsposHOrbi$ms,fullmsposNH4Orbi$ms)

write.csv2(annotation_posOrbi,file="annotation_posOrbi.csv")


PeakGroupMS1<-PeakGroupMS1(annotation_posOrbi)


fullmsnegOrbiMedium<-FullMS(fileMedium, databaseHmenos,mzw = 0.001,ppm_tol = 5,Peak_Assy=5, rtw=NULL,dmzgap=25 ,ppm=TRUE ,dmzdens=5,
                       drtdens=250,drtgap=500,drtsmall=20,drtfill=10 ,drttotal=200 ,
                       minpeak=4,recurs=2,weight=1 , SB=2, SN=1.5,minint=1000 , maxint=1000000000 ,ended=1,ion_mode ="negative")




annotation_pos_neg_Orbi_Medium<-rbind(annotation_posOrbi,fullmsnegOrbiMedium$ms)
write.csv2(annotation_pos_neg_Orbi_Medium,file="annotation_pos_neg_Orbi_Medium.csv")



#### SECTION 5: Figure S1


plot_EIC(fullmsposNH4,peakID=162)
plot_EIC(fullmsposH,peakID=125)

ScoresMS1<-ScoresMS1(fullmsposNH4,fullmsposH,ID1=162,ID2=125)

#### SECTION 6: Figure 2a

plot_EIC(fullmsposH,peakID=441)
plot_EIC(fullmsposH,peakID=437)

ScoresMS1<-ScoresMS1(fullmsposH,fullmsposH,ID1=441,ID2=437)


#### SECTION 7: Figure 2b

plot_EIC(fullmsposHOrbi,peakID=330)
plot_EIC(fullmsposHOrbi,peakID=346)

ScoresMS1<-ScoresMS1(fullmsposHOrbi,fullmsposHOrbi,ID1=330,ID2=346)


### SECTION 8 : ALL IONS FRAGMENTATION LC-Q-EXACTIVE Orbitrap
#Reading the file.mzXML

file<-"12.mzXML"
file<-"12M.mzXML"

### separate by CE

CE.isolation("12M.mzXML","12M_Orbi")
CE.isolation("12.mzXML","12_Orbi")

#Reading the file.mzXML FOR CELL
fileMS_Orbi<-"12_OrbifullMSpp.mzXML"
fileMS2CE30<-"12_Orbi30pp.mzXML"

#Reading the file.mzXML FOR CELL MEDIUM
fileMS_MEDIUM<-"12M_OrbifullMSpp.mzXML"
fileMS2CE30_MEDIUM<-"12M_Orbi30pp.mzXML"


#Reading the  database file:

library(readxl)

databaseneg<- read_excel("AIF_Quique_database_neg.xlsx")

databasepos<- read_excel("AIF_Quique_database.xlsx")


###### FOR CELL SAMPLE  POSITIVE
AIF_Orbi_Cell_pos<-AIF(fileMS_Orbi,fileMS2CE30,databasepos,ppm_tol=5,
                       CE=30, ion_mode = "positive", 
                       drtsmallMS1 = 2,drtgap =5,drttotal = 10,drtsmallMS2=2)


### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Cell_pos,a=0,database = databasepos)
### annotate metabolites which at least one of the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Cell_pos,a=1,database = databasepos)


###### FOR CELL SAMPLE  NEGATIVE

databaseneg<- read_excel("AIF_Quique_database_neg.xlsx")

AIF_Orbi_Cell_neg<-AIF(fileMS,fileMS2CE30,databaseneg,ppm_tol=5,
                       CE=30, ion_mode = "negative",drtsmallMS1 = 2,drtgap =15,drttotal = 20,drtsmallMS2=2)


### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Cell_neg,a=0,database = databaseneg)
### annotate metabolites which at least one of the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Cell_neg,a=1,database = databaseneg)



###### MEDIUM SAMPLE POS

AIF_Orbi_Medium_pos<-AIF(fileMS_MEDIUM,fileMS2CE30_MEDIUM,databasepos,ppm_tol=5,
                         CE=30, ion_mode = "positive",drtsmallMS1 = 2,drtgap =15,drttotal = 20,drtsmallMS2=2)

       
### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Medium_pos,a=0,database = databasepos)
### annotate metabolites which at least one of the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Medium_pos,a=1,database = databasepos)


###### FOR MEDIUM SAMPLE NEG

database<-databaseneg
AIF_Orbi_Medium_neg<-AIF(fileMS_MEDIUM,fileMS2CE30_MEDIUM,databaseneg,ppm_tol=5,
                         CE=30, ion_mode = "negative")


### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Medium_neg,a=0,database = databaseneg)
### annotate metabolites which all-1 of the fragments aligns to the precursor.
Filter_AIF(AIF_Orbi_Medium_neg,a=1,database = databaseneg)



### SECTION 9 : DATA INDEPENDENT ACQUISITION BY LC-qTOF
#Reading the file.mzXML

file<-"qTOF_Urine.mzXML"

### separate by CE

CE.isolation("qTOF_Urine.mzXML","fileposB")

#Reading the SEPARATED FILES BY COLLISION ENERGY
fileMS<-"qTOF_Urine.mzXML"
fileMS2CE5<-"fileposB5pp.mzXML"
fileMS2CE10<-"fileposB10pp.mzXML"
fileMS2CE20<-"fileposB20pp.mzXML"


#Reading the database file:


library(readxl)
databasepos<- read_excel("AIF_Quique_database.xlsx")


###### FOR urine sample at CE 5 eV
aif5<-AIF(fileMS,fileMS2CE5,databasepos, ion_mode = "positive",CE=5,
          drtsmallMS1 = 100,drtgap =25,drtdens = 20,drttotal = 100,drtsmallMS2=30)

### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(aif5,a=0,database = databasepos)

### annotate metabolites which 1 of the fragments aligns to the precursor.
Filter_AIF(aif5,a=1,database = databasepos)

###### FOR urine sample at CE 10 eV
aif10<-AIF(fileMS,fileMS2CE10,databasepos, ion_mode = "positive",CE=10,
           drtsmallMS1 = 100,drtgap =25,drtdens = 20,drttotal = 100,drtsmallMS2=30)


### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(aif10,a=0,database = databasepos)

### annotate metabolites which 1 of the fragments aligns to the precursor.
Filter_AIF(aif10,a=1,database = databasepos)


###### FOR urine sample at CE 20 eV
aif20<-AIF(fileMS,fileMS2CE20,databasepos, ion_mode = "positive",CE=20,
           drtsmallMS1 = 100,drtgap =25,drtdens = 20,drttotal = 100,drtsmallMS2=30,dmzgap = 50,dmzdensMS1 = 15)


### annotate metabolites which all the fragments aligns to the precursor.
Filter_AIF(aif20,a=0,database = databasepos)

### annotate metabolites which 1 of the fragments aligns to the precursor.
Filter_AIF(aif20,a=1,database = databasepos)


Peakgroup<-PeakGroup(aif5,aif10,aif20)


#### SECTION RESULTS 2.3

#GLUTAMINE EXAMPLE

peakGF<-read.csv("PeakGroup Glutamine.csv",check.names=FALSE,row.names = 1)



Scores5<-ScoresDIA(peakGF,aif5,ID1=280, ID2 = 100,CE=5)
Scores5B<-ScoresDIA(peakGF,aif5,ID1=280, ID2 = 338,CE=5)
Scores10a<-ScoresDIA(peakGF,aif10,ID1=280, ID2 = 196,CE=10)
Scores10b<-ScoresDIA(peakGF,aif10,ID1=280, ID2 =580 ,CE=10)
Scores20<-ScoresDIA(peakGF,aif20,ID1=280, ID2 =318 ,CE=20)



#PHENYLACETYLGLUTAMINE EXAMPLE

peakGF<-read.csv("PeakGroup Phenylacetylglutamine.csv",check.names=FALSE,row.names = 1)


Scores5<-ScoresDIA(peakGF,aif5,ID1=871, ID2 = 102,CE=5)
Scores5b<-ScoresDIA(peakGF,aif5,ID1=871, ID2 = 337,CE=5)
Scores5c<-ScoresDIA(peakGF,aif5,ID1=871, ID2 = 362,CE=5)
Scores5d<-ScoresDIA(peakGF,aif5,ID1=871, ID2 = 420,CE=5)

Scores10a<-ScoresDIA(peakGF,aif10,ID1=871, ID2 = 192,CE=10)
Scores10a
Scores10b<-ScoresDIA(peakGF,aif10,ID1=871, ID2 = 581,CE=10)
Scores10b
Scores10c<-ScoresDIA(peakGF,aif10,ID1=871, ID2 = 644,CE=10)
Scores10c
Scores10E<-ScoresDIA(peakGF,aif10,ID1=871, ID2 = 719,CE=10)
Scores10E

Scores20A<-ScoresDIA(peakGF,aif20,ID1=871, ID2 = 317,CE=20)
Scores20A
Scores20B<-ScoresDIA(peakGF,aif20,ID1=871, ID2 = 761,CE=20)
Scores20C<-ScoresDIA(peakGF,aif20,ID1=871, ID2 = 830,CE=20)
Scores20D<-ScoresDIA(peakGF,aif20,ID1=871, ID2 = 899,CE=20)


#PHENYLALANINE EXAMPLE


peakGF<-read.csv("PeakGroup Phenylalanine.csv",check.names=FALSE,row.names = 1)

Scores5<-ScoresDIA(peakGF,aif5,ID1=356, ID2 = 264,CE=5)
Scores10<-ScoresDIA(peakGF,aif10,ID1=356, ID2 = 488,CE=10)
Scores20<-ScoresDIA(peakGF,aif20,ID1=356, ID2 = 536,CE=20)
Scores20B<-ScoresDIA(peakGF,aif20,ID1=356, ID2 = 679,CE=20)



### GLUTAMINE ORBITRAP

Peakgroup<-PeakGroup(AIF_Orbi_Cell_pos,AIF_Orbi_Cell_pos,AIF_Orbi_Cell_pos)

peakGF<-read.csv("PeakGroup Glutathione.csv",check.names=FALSE,row.names = 1)


Scores1<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =5656,CE=30)
Scores2<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =4724,CE=30)
Scores3<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =4299,CE=30)
Scores4<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =3719,CE=30)
Scores5<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =3159,CE=30)
Scores6<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =2539,CE=30)
Scores7<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =1166,CE=30)
Scores8<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=8926, ID2 =974,CE=30)


## example METHIONINE

peakGF<-read.csv("PeakGroup Methionine.csv",check.names=FALSE,row.names = 1)

Scores1<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=3021, ID2 =3313,CE=30)
Scores2<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=3021, ID2 =2039,CE=30)
Scores3<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=3021, ID2 =458,CE=30)
Scores4<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=3021, ID2 =143,CE=30)


Scores1<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=3021, ID2 =3,CE=30)


## example METHIONINE


peakGF<-read.csv("PeakGroup Valine.csv",check.names=FALSE,row.names = 1)

Scores1<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=1716, ID2 =1969,CE=30)
Scores2<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=1716, ID2 =1165,CE=30)
Scores3<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=1716, ID2 =912,CE=30)



## example TYROSINE


peakGF<-read.csv("PeakGroup Tyrosine.csv",check.names=FALSE,row.names = 1)

Scores1<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=5032, ID2 =3817,CE=30)
Scores2<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=5032, ID2 =3458,CE=30)
Scores3<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=5032, ID2 =2925,CE=30)
Scores4<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=5032, ID2 =2739,CE=30)
Scores5<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=5032, ID2 =1661,CE=30)
Scores6<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=5032, ID2 =1513,CE=30)


Scores1<-ScoresDIA(peakGF,AIF_Orbi_Cell_pos,ID1=3817, ID2 =5,CE=3)

